==> nsd-1.2.3.tar.gz: nsd-1.2.3/plugins.h <==
/*
 * plugins.h -- set of routines to manage plugins.
 *
 * Erik Rozendaal, <erik@nlnetlabs.nl>
 *
 * Copyright (c) 2003, NLnet Labs. All rights reserved.
 *
 * This software is an open source.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the NLNET LABS nor the names of its contributors may
 * be used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef _PLUGINS_H_
#define _PLUGINS_H_

#ifdef PLUGINS

#include "nsd-plugin.h"

extern nsd_plugin_id_type maximum_plugin_count;

void plugin_init(struct nsd *nsd);
int plugin_load(const char *name, const char *arg);
void plugin_finalize_all(void);
nsd_plugin_callback_result_type plugin_database_reloaded(void);

nsd_plugin_callback_result_type query_received_callbacks(
	nsd_plugin_callback_args_type *args,
	void **data);
nsd_plugin_callback_result_type query_processed_callbacks(
	nsd_plugin_callback_args_type *args,
	void **data);
int handle_callback_result(
	nsd_plugin_callback_result_type result,
	nsd_plugin_callback_args_type *args);

#endif /* PLUGINS */

#endif /* _PLUGINS_H_ */

==> nsd_2.1.0.orig.tar.gz: nsd-2.1.0/plugins.h <==
/*
 * plugins.h -- set of routines to manage plugins.
 *
 * Erik Rozendaal, <erik@nlnetlabs.nl>
 *
 * Copyright (c) 2003-2004, NLnet Labs. All rights reserved.
 *
 * This software is an open source.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the NLNET LABS nor the names of its contributors may
 * be used to endorse or promote products derived from this software without
 * specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef _PLUGINS_H_
#define _PLUGINS_H_

#ifdef PLUGINS

#include "nsd-plugin.h"

extern nsd_plugin_id_type maximum_plugin_count;

void plugin_init(struct nsd *nsd);
int plugin_load(struct nsd *nsd, const char *name, const char *arg);
void plugin_finalize_all(void);
nsd_plugin_callback_result_type plugin_database_reloaded(void);

nsd_plugin_callback_result_type query_received_callbacks(
	nsd_plugin_callback_args_type *args,
	void **data);
nsd_plugin_callback_result_type query_processed_callbacks(
	nsd_plugin_callback_args_type *args,
	void **data);
int handle_callback_result(
	nsd_plugin_callback_result_type result,
	nsd_plugin_callback_args_type *args);

#endif /* PLUGINS */

#endif /* _PLUGINS_H_ */
